@@ -346,10 +346,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define SIZEOF_CHAR 1
@@ -371,7 +371,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -414,7 +414,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -472,7 +472,7 @@
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
-/* #undef HAVE_GCC_ATOMIC_BUILTINS */
+#define HAVE_GCC_ATOMIC_BUILTINS 1
 /* #undef HAVE_GCC_C11_ATOMICS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
@@ -484,15 +484,14 @@
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
 /* #undef _LARGEFILE64_SOURCE */
-/* #undef _FILE_OFFSET_BITS */
 
 #define TIME_WITH_SYS_TIME 1
 
-#define STACK_DIRECTION 1
+#define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "hppa"
-#define DEFAULT_MACHINE "hppa"
+#define MACHINE_TYPE "alpha"
+#define DEFAULT_MACHINE "alpha"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -609,20 +608,20 @@
   Important storage engines (those that really need define 
   WITH_<ENGINE>_STORAGE_ENGINE for the whole server)
 */
-/* #undef WITH_MYISAM_STORAGE_ENGINE */
-/* #undef WITH_MYISAMMRG_STORAGE_ENGINE */
-/* #undef WITH_HEAP_STORAGE_ENGINE */
+#define WITH_MYISAM_STORAGE_ENGINE 1
+#define WITH_MYISAMMRG_STORAGE_ENGINE 1
+#define WITH_HEAP_STORAGE_ENGINE 1
 /* #undef WITH_INNOBASE_STORAGE_ENGINE */
-/* #undef WITH_XTRADB_STORAGE_ENGINE */
-/* #undef WITH_CSV_STORAGE_ENGINE */
-/* #undef WITH_PARTITION_STORAGE_ENGINE */
-/* #undef WITH_PERFSCHEMA_STORAGE_ENGINE */
+#define WITH_XTRADB_STORAGE_ENGINE 1
+#define WITH_CSV_STORAGE_ENGINE 1
+#define WITH_PARTITION_STORAGE_ENGINE 1
+#define WITH_PERFSCHEMA_STORAGE_ENGINE 1
 /* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
 #if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
 # define HAVE_NDB_BINLOG 1
 #endif
-/* #undef WITH_ARIA_STORAGE_ENGINE */
-/* #undef USE_ARIA_FOR_TMP_TABLES */
+#define WITH_ARIA_STORAGE_ENGINE 1
+#define USE_ARIA_FOR_TMP_TABLES 1
 
 #define DEFAULT_MYSQL_HOME "/usr/local"
 #define SHAREDIR "/usr/local/share/mysql"
@@ -637,16 +636,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 25
+#define MYSQL_VERSION_PATCH 30
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.25"
+#define PACKAGE_STRING "MySQL Server 10.0.30"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.25"
-#define VERSION "10.0.25"
+#define PACKAGE_VERSION "10.0.30"
+#define VERSION "10.0.30"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
