@@ -11,17 +11,17 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.0.25-MariaDB"
+#define MYSQL_SERVER_VERSION		"10.0.30-MariaDB"
 #define MYSQL_BASE_VERSION		"mysqld-10.0"
 #define MARIADB_BASE_VERSION		"mariadb-10.0"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100025
+#define MYSQL_VERSION_ID		100030
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/var/run/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mariadb-server-10.0.25p0v1"
+#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mariadb-server-10.0.30v1"
 
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
